from sqlalchemy import create_engine
from ipc.validator.dataset_metadata_validator import collect_error_df
from ipc.validator.settings import DB_NAME, TABLE
import traceback as tb

if __name__ == '__main__':
    # Run the error collection routine
    try:
        # Get the compiled error table.
        compiled_error_df = collect_error_df()
        # Create an SQLAlchemy connection to an SQLite object with name: DB_NAME
        engine = create_engine(f'sqlite:///ipc/validator/{DB_NAME}')
        conn = engine.connect()
        if not compiled_error_df.empty:
            # If the DB exists, append to the table.
            compiled_error_df.to_sql(TABLE, conn, if_exists='append', chunksize=1000)
            print(f'Errors added to table: {TABLE}\nDB: {DB_NAME}')
        else:
            print(f'Error compiling errors')
        conn.close()
    except Exception as e:
        print(tb.format_exc())
